@@ -3,9 +3,9 @@ import sys
 from cowait.tasks import TaskDefinition
 from cowait.engine.errors import TaskCreationError
 from cowait.utils import parse_task_image_name
-from ..context import cowaitContext
+from ..context import CowaitContext
 from ..utils import ExitTrap, get_context_cluster, printheader
-from .push import push
+from .build import build as build_cmd
 
 
 def run(
@@ -22,14 +22,14 @@ def run(
     cpu: str = '0',
     memory: str = '0',
 ):
-    context = cowaitContext.open()
+    context = CowaitContext.open()
     cluster = get_context_cluster(context, provider)
 
     # figure out image name
     image, task = parse_task_image_name(task, None)
     if image is None:
         if build:
-            push()
+            build_cmd()
         image = context.get_image_name()
 
     # default to agent as upstream
